@@ -1,11 +1,26 @@
-import numpy as np
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ==============================================================================
+"""Contains CategoricalCrossentropy class."""
 
+import numpy as np
 from .loss_function import LossFunction
 
 
 class CategoricalCrossentropy(LossFunction):
-    """
-    Cross entropy loss function.
+    """Cross entropy loss function.
+
+    A loss function used in order to classify 2 or more categories. This class is commonly used to classify more than 2
+    categories, such that if is not, binary cross-entropy is used.
     """
 
     def __init__(self, name="cross_entropy"):
